@@ -41,6 +41,10 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <stdint.h>
 
+#include "pcsclite.h"
+#include "readerfactory.h"
+#include "wintypes.h"
+
 	/**
 	 * Define an exported public reader state structure so each
 	 * application gets instant notification of changes in state.
