@@ -39,9 +39,13 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifndef __ifdwrapper_h__
 #define __ifdwrapper_h__
 
-	LONG IFDOpenIFD(READER_CONTEXT *);
-	LONG IFDCloseIFD(READER_CONTEXT *);
-	LONG IFDPowerICC(READER_CONTEXT *, DWORD, PUCHAR, /*@out@*/ PDWORD);
+#include "ifdhandler.h"
+#include "readerfactory.h"
+#include "wintypes.h"
+
+	RESPONSECODE IFDOpenIFD(READER_CONTEXT *);
+	RESPONSECODE IFDCloseIFD(READER_CONTEXT *);
+	RESPONSECODE IFDPowerICC(READER_CONTEXT *, DWORD, PUCHAR, /*@out@*/ PDWORD);
 	LONG IFDStatusICC(READER_CONTEXT *, /*@out@*/ PDWORD);
 	LONG IFDControl_v2(READER_CONTEXT *, PUCHAR, DWORD, /*@out@*/ PUCHAR,
 		PDWORD);
@@ -49,8 +53,8 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 		DWORD, LPDWORD);
 	LONG IFDTransmit(READER_CONTEXT *, SCARD_IO_HEADER,
 		PUCHAR, DWORD, /*@out@*/ PUCHAR, PDWORD, PSCARD_IO_HEADER);
-	LONG IFDSetPTS(READER_CONTEXT *, DWORD, UCHAR, UCHAR, UCHAR, UCHAR);
-	LONG IFDSetCapabilities(READER_CONTEXT *, DWORD, DWORD, PUCHAR);
-	LONG IFDGetCapabilities(READER_CONTEXT *, DWORD, PDWORD, /*@out@*/ PUCHAR);
+	RESPONSECODE IFDSetPTS(READER_CONTEXT *, DWORD, UCHAR, UCHAR, UCHAR, UCHAR);
+	RESPONSECODE IFDSetCapabilities(READER_CONTEXT *, DWORD, DWORD, PUCHAR);
+	RESPONSECODE IFDGetCapabilities(READER_CONTEXT *, DWORD, PDWORD, /*@out@*/ PUCHAR);
 
 #endif							/* __ifdwrapper_h__ */
