@@ -700,7 +700,7 @@ int main(int argc, char **argv)
 	}
 
 	/*
-	 * post initialistion
+	 * post initialization
 	 */
 	Init = FALSE;
 
@@ -738,7 +738,7 @@ int main(int argc, char **argv)
 
 	(void)signal(SIGPIPE, SIG_IGN);
 	(void)signal(SIGHUP, SIG_IGN);	/* needed for Solaris. The signal is sent
-				 * when the shell is existed */
+				 * when the shell is exited */
 
 #if !defined(PCSCLITE_STATIC_DRIVER) && defined(USE_USB)
 	/*
@@ -760,7 +760,7 @@ int main(int argc, char **argv)
 	RFWaitForReaderInit();
 #endif
 
-	/* initialisation succeeded */
+	/* initialization succeeded */
 	if (pipefd[1] >= 0)
 	{
 		char buf = 0;
@@ -776,6 +776,13 @@ int main(int argc, char **argv)
 		pipefd[1] = -1;
 	}
 
+	if (AutoExit)
+	{
+		Log2(PCSC_LOG_DEBUG, "Starting suicide alarm in %d seconds",
+			TIME_BEFORE_SUICIDE);
+		alarm(TIME_BEFORE_SUICIDE);
+	}
+
 	SVCServiceRunLoop();
 
 	Log1(PCSC_LOG_ERROR, "SVCServiceRunLoop returned");
